
/*********************************************************/
/*************** EXAMPLE OF GWNBR ***********************/
/*********************************************************/

/********* importing data - method 1 ********/
%let path=type your path;
libname es "&path";
data data_gwnbr;set es.data_gwnbr;run; 
data espiritosanto;set es.espiritosanto;run;

/********* importing data - method 2 ********/

proc import datafile="&path\data_gwnbr.txt"
out=data_gwnbr replace;
run;
proc import datafile="&path\shape_espiritosanto.txt"
out=Espiritosanto replace;
run;

/********* reading SAS Macros ********/
%include "&path\GWNBR.sas";


/********************************************************/
/**************** POISSON REGRESSION ********************/
/********************************************************/

proc genmod data=data_gwnbr;
model fleet = industry / dist=poi;
run;

/********************************************************/
/*********** NEGATIVE BINOMIAL REGRESSION****************/
/********************************************************/

proc genmod data=data_gwnbr;
model fleet = industry / dist=negbin;
run;

/********************************************************/
/********** GOLDEN SECTION SEARCH ***********************/
/********************************************************/

/****** GWR=GWNBR and METHOD=FIXED AND TYPE=AIC *********/
%golden(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,method=fixed,
type=aic,gwr=local,out=band);
proc gplot data=band;
plot res1*h1 res2*h2 /overlay vaxis=axis1 name="band_";
axis1 label=(a=90 'AICc');
label h1='Bandwidth';
run;
quit;  

/****** GWR=GWNBR and METHOD=FIXED AND TYPE=CV *********/
%golden(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,method=fixed,
type=cv,gwr=local,out=band);	
proc gplot data=band;
plot res1*h1 res2*h2 /overlay vaxis=axis1 name="band_";
axis1 label=(a=90 'Cross-Validation Score');
label h1='Bandwidth';
run;
quit;  

/****** GWR=GWNBR and METHOD=ADAPTIVE1 AND TYPE=AIC *********/
%golden(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,method=adaptive1,
type=aic,gwr=local,out=band);
proc gplot data=band;
plot res1*h1 res2*h2 /overlay vaxis=axis1 name="band_";
axis1 label=(a=90 'AICc');
label h1='Bandwidth';
run;
quit; 

/****** GWR=GWNBR and METHOD=ADAPTIVE1 AND TYPE=CV *********/
%golden(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,method=adaptive1,
type=cv,gwr=local,out=band);	
proc gplot data=band;
plot res1*h1 res2*h2 /overlay vaxis=axis1 name="band_";
axis1 label=(a=90 'Cross-Validation Score');
label h1='Bandwidth';
run;
quit;  

/****** GWR=GWNBRg and METHOD=FIXED AND TYPE=AIC *********/
%golden(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,method=fixed,
type=aic,gwr=global,out=band);
proc gplot data=band;
plot res1*h1 res2*h2 /overlay vaxis=axis1 name="band_";
axis1 label=(a=90 'AICc');
label h1='Bandwidth';
run;
quit; 	

/****** GWR=GWNBRg and METHOD=FIXED AND TYPE=CV *********/
%golden(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,method=fixed,
type=cv,gwr=global,out=band);	
proc gplot data=band;
plot res1*h1 res2*h2 /overlay vaxis=axis1 name="band_";
axis1 label=(a=90 'Cross-Validation Score');
label h1='Bandwidth';
run;
quit;  

/****** GWR=GWNBRg and METHOD=ADAPTIVE1 AND TYPE=AIC *********/
%golden(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,method=adaptive1,
type=aic,gwr=global,out=band);	
proc gplot data=band;
plot res1*h1 res2*h2 /overlay vaxis=axis1 name="band_";
axis1 label=(a=90 'AICc');
label h1='Bandwidth';
run;
quit; 

/****** GWR=GWNBRg and METHOD=ADAPTIVE1 AND TYPE=CV *********/
%golden(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,method=adaptive1,
type=cv,gwr=global,out=band);	
proc gplot data=band;
plot res1*h1 res2*h2 /overlay vaxis=axis1 name="band_";
axis1 label=(a=90 'Cross-Validation Score');
label h1='Bandwidth';
run;
quit;  

/****** GWR=GWPR and METHOD=FIXED AND TYPE=AIC *********/
%golden(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,method=fixed,
type=aic,gwr=poisson,out=band);		
proc gplot data=band;
plot res1*h1 res2*h2 /overlay vaxis=axis1 name="band_";
axis1 label=(a=90 'AICc');
label h1='Bandwidth';
run;
quit; 

/****** GWR=GWPR and METHOD=FIXED AND TYPE=CV *********/
%golden(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,method=fixed,
type=cv,gwr=poisson,out=band);		
proc gplot data=band;
plot res1*h1 res2*h2 /overlay vaxis=axis1 name="band_";
axis1 label=(a=90 'Cross-Validation Score');
label h1='Bandwidth';
run;
quit;  

/****** GWR=GWPR and METHOD=ADAPTIVE1 AND TYPE=AIC *********/
%golden(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,method=adaptive1,
type=aic,gwr=poisson,out=band);		
proc gplot data=band;
plot res1*h1 res2*h2 /overlay vaxis=axis1 name="band_";
axis1 label=(a=90 'AICc');
label h1='Bandwidth';
run;
quit; 

/****** GWR=GWPR and METHOD=ADAPTIVE1 AND TYPE=CV *********/
%golden(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,method=adaptive1,
type=cv,gwr=poisson,out=band);		
proc gplot data=band;
plot res1*h1 res2*h2 /overlay vaxis=axis1 name="band_";
axis1 label=(a=90 'Cross-Validation Score');
label h1='Bandwidth';
run;
quit;  

/********************************************************/
/*********************** GWNBR **************************/
/********************************************************/

/********** GWR=GWNBR and METHOD=FIXED ***********/
%gwnbr(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,h=29.4, 
gwr=local, method=fixed,geocod=geocod,out=gwnbr);

%gwnbr(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,h=53.200292, 
gwr=local, method=fixed,geocod=geocod,out=gwnbr);

/********** GWR=GWNBR and METHOD=ADAPTIVE1 ***********/
%gwnbr(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,h=18, 
gwr=local, method=adaptive1,geocod=geocod,out=gwnbr);

%gwnbr(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,h=49, 
gwr=local, method=adaptive1,geocod=geocod,out=gwnbr);

/********** GWR=GWNBRg and METHOD=FIXED ***********/
%gwnbr(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,h=53.068412, 
gwr=global, method=fixed,geocod=geocod,out=gwr);

%gwnbr(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,h=53.2, 
gwr=global, method=fixed,geocod=geocod,out=gwr);

/********** GWR=GWNBRg and METHOD=ADAPTIVE1 ***********/
%gwnbr(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,h=34, 
gwr=global, method=adaptive1,geocod=geocod,out=gwr);

%gwnbr(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,h=49, 
gwr=global, method=adaptive1,geocod=geocod,out=gwr);

/********** GWR=GWPR and METHOD=FIXED ***********/
%gwnbr(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,h=9.3796134, 
gwr=poisson,method=fixed,geocod=geocod,out=gwr);

%gwnbr(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,h=28.5, 
gwr=poisson,method=fixed,geocod=geocod,out=gwr);

/********** GWR=GWPR and METHOD=ADAPTIVE1 ***********/
%gwnbr(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,h=5, 
gwr=poisson,method=adaptive1,geocod=geocod,out=gwr);

%gwnbr(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,h=41, 
gwr=poisson,method=adaptive1,geocod=geocod,out=gwr);

/********************************************************/
/****** SURFACE OF THE PARAMETERS ESTIMATES *************/
/********************************************************/

%macro map(data=,var=);
goptions reset=all;
proc gmap data=&data map=Espiritosanto all;
id geocod;
choro &var / legend=legend1;
legend1 position=(middle right) across=1 mode=reserve label=(position=top j=c);
run;
quit;
%mend map;

/** GWPR **/
%gwnbr(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,h=10,gwr=poisson,geocod=geocod,method=adaptive1);
data _parametersp_;merge _parameters_ _sig_parameters2_;run;
data alphap; set _alpha_; run;
data _resp_; merge _res_ data_gwnbr; run;

%map(data=_parametersp_,var=intercept);
%map(data=_parametersp_,var=industry);
%map(data=alphap,var=alphai);

/** GWNBR **/
%gwnbr(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,h=53.068412,gwr=global,geocod=geocod,method=fixed);
data _parametersg_;merge _parameters_ _sig_parameters2_;run;
data alphag; set _alpha_; run;
data _resg_; merge _res_ data_gwnbr; run;

%map(data=_parametersg_,var=intercept);
%map(data=_parametersg_,var=industry);
%map(data=alphag,var=alphai);

/** GWNBRg **/
%gwnbr(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,h=53.200292,gwr=local,geocod=geocod,method=fixed);
data _parametersl_;merge _parameters_ _sig_parameters2_;run;
data alphal; set _alpha_; run;
data _resl_; merge _res_ data_gwnbr; run;

%map(data=_parametersl_,var=intercept);
%map(data=_parametersl_,var=industry);
%map(data=alphal,var=alphai);

/********************************************************/
/****** SIGNIFICANCE OF THE PARAMETERS ESTIMATES ********/
/********************************************************/

%macro sigmap(data=,var=,where=);
goptions reset=all;
proc gmap data=&data map=Espiritosanto all;
id geocod;
&where;
choro &var / legend=legend1;
legend1 position=(middle right) across=1 mode=reserve label=(position=top j=c);
run;
quit;
%mend sigmap;

/** GWPR **/

%sigmap(data=_parametersp_,var=intercept,where=where sig_Intercept ne 'not significant at 90%');
%sigmap(data=_parametersp_,var=industry,where=where sig_INDUSTRY ne 'not significant at 90%');
%sigmap(data=alphap,var=alphai,where=where SIG_ALPHA ne 'not significant at 90%');

/** GWNBR **/

%sigmap(data=_parametersg_,var=intercept,where=where sig_Intercept ne 'not significant at 90%');
%sigmap(data=_parametersg_,var=industry,where=where sig_INDUSTRY ne 'not significant at 90%');
%sigmap(data=alphag,var=alphai,where=where SIG_ALPHA ne 'not significant at 90%');

/** GWNBRg **/

%sigmap(data=_parametersl_,var=intercept,where=where sig_Intercept ne 'not significant at 90%');
%sigmap(data=_parametersl_,var=industry,where=where sig_INDUSTRY ne 'not significant at 90%');
%sigmap(data=alphal,var=alphai,where=where SIG_ALPHA ne 'not significant at 90%');


/* STATIONARITY TESTS */
%estac(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,h=10,
gwr=poisson,method=adaptiven,alphag=,rep=9,geocod=geocod);

%estac(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,h=53.068412,
gwr=global,method=fixed,alphag=,rep=9,geocod=geocod);

%estac(data=data_gwnbr,y=fleet,x=industry,lat=y,long=x,h=53.200292,
gwr=local,method=fixed,alphag=,rep=9,geocod=geocod);
